<link href="{{  url_for('static', filename='libs/fomantic-ui/semantic.min.css') }}" integrity="sha512-pbLYRiE96XJxmJgF8oWBfa9MdKwuXhlV7vgs2LLlapHLXceztfcta0bdeOgA4reIf0WH67ThWzA684JwkM3zfQ==" rel="stylesheet" />
<link href="{{  url_for('static', filename='libs/datatables.net-se/dataTables.semanticui.min.css') }}" integrity="sha512-e9uBgQc3QPZn0PNG5ZzUATySIV/ZkBF8CJBDjAdlWHKhOGPNMza/fVZCETIQ+/swJSmAOni8E26d4Hk3e5VLMA==" rel='stylesheet' type='text/css'>
<link href="{{  url_for('static', filename='libs/datatables.net-buttons-se/buttons.semanticui.min.css') }}" integrity="sha512-TYx3LuLpvSb1HPUM66g0VJ7zTH5E9G2SmvRVlM4DTpRe4J2dq4iwYPTBDI2BHvSTZpePlDtR+lo7m2bpWmpKPQ==" rel='stylesheet' type='text/css'>
<link href="{{  url_for('static', filename='libs/billboard.js/billboard.min.css') }}" integrity="sha512-RMOXiaUbYERixbCxwbAyhJcq/KDpbXMZGLLUbexHB5JWdXsZONmsv2tLycOcTnAGCDZ9qPGG5pbd6bnL8YRhSw==" rel="stylesheet" />
<link href="{{  url_for('static', filename='css/fonts.css') }}" rel="stylesheet" />

<script src="{{ url_for('static', filename='libs/moment.js/moment-with-locales.min.js') }}" integrity="sha512-42PE0rd+wZ2hNXftlM78BSehIGzezNeQuzihiBCvUEB3CVxHvsShF86wBWwQORNxNINlBPuq7rG4WWhNiTVHFg=="></script>
<script src="{{ url_for('static', filename='libs/jquery/jquery.min.js') }}"  integrity="sha512-894YE6QWD5I59HgZOGReFYm4dnWc1Qt5NtvYSaNcOP+u1T9qYdvdihz0PPSiiqn/+/3e7Jo4EaG7TubfWGUrMQ=="></script>
<script src="{{ url_for('static', filename='libs/fomantic-ui/semantic.min.js') }}" integrity="sha512-t5mAtfZZmR2gl5LK7WEkJoyHCfyzoy10MlerMGhxsXl3J7uSSNTAW6FK/wvGBC8ua9AFazwMaC0LxsMTMiM5gg=="></script>
<script src="{{ url_for('static', filename='libs/datatables.net/jquery.dataTables.min.js') }}" integrity="sha512-MOsicOaJyNWPgwMOE1q4sTPZK6KuUQTMBhkmzb0tFVSRxgx3VnGTwIyRme/IhBJQdWJkfTcIKozchO11ILrmSg=="></script>
<script src="{{ url_for('static', filename='libs/datatables.net-buttons/dataTables.buttons.min.js') }}" integrity="sha512-QT3oEXamRhx0x+SRDcgisygyWze0UicgNLFM9Dj5QfJuu2TVyw7xRQfmB0g7Z5/TgCdYKNW15QumLBGWoPefYg=="></script>
<script src="{{ url_for('static', filename='libs/datatables.net-buttons/buttons.html5.min.js') }}" integrity="sha512-BdN+kHA7QfWIcQE3WMwSj5QAvVUrSGxJLv7/yuEEypMOZBSJ1VKGr9BSpOew+6va9yfGUACw/8Yt7LKNn3RKRA==" crossorigin="anonymous" referrerpolicy="no-referrer"></script>
<script src="{{ url_for('static', filename='libs/datatables.net-buttons/buttons.colVis.min.js') }}" integrity="sha512-TDM0Ek51cJSpP8Btld1ahY8LpMImyQ1k+Ve81qGMdjBLKhADu99JQrUWDuRnT8M0qfkJb+Mt+ZwMaMi46UXA8g=="></script>
<script src="{{ url_for('static', filename='libs/datatables.net-buttons-se/buttons.semanticui.min.js') }}" integrity="sha512-qmAhnVf7i7pJuJwzvlJFbZv3VDoenpg9vwe2jJDkOF0Hu2XG/CyP8hFIerq/otdg2GoOBJUbbtqwGd5lSZ/LGg=="></script>
<script src="{{ url_for('static', filename='libs/datatables.net-se/dataTables.semanticui.min.js') }}" integrity="sha512-bhjwBvv8tKytSAgGnPmRpJq47qjFD0BOr6zuTlbq5a318FPQFu/D/go6+s4YWWitCr4DGbc2GEhqZtALJr4Cvw=="></script>
<script src="{{ url_for('static', filename='libs/billboard.js/billboard.pkgd.min.js')}}" integrity="sha512-OOmBcDdvKI70Jl7azzoCyGuWBTaUiLvxDkQYaU5G3Pufg2RsLV9p6zu253rmguRTpkt0X3HMevi8n0lic/32wg=="></script>
