body {
  margin: 0;
  font-family: "Open Sans", sans-serif;
  font-size: 1.2rem;
}

a {
  color: #2E5D8C;
  text-decoration: none;
}

h1.ui.header.no-margin-bottom {
  margin-bottom: 0;
}

.ui.select-environment > i.dropdown.icon {
  margin: 0.4em 0 0 1em !important;
}

.ui.select-environment.loading.selection.dropdown > i.dropdown.icon {
  padding: 1em 0.5em !important;
  margin: 0 !important;
}

.ui.grid.padding-bottom {
  padding-bottom: 4em !important;
}

.status {
  width: 13.2em;
  text-align: center;
  display: block;
}

.ui[class*="very basic"].table.dataTable > thead > tr:first-child > th {
  padding-top: 0.8em !important;
  padding-bottom: 0.7em !important;
}

.ui[class*="very compact"].table>tbody>tr>td,
.ui[class*="very compact"].table>tfoot>tr>td,
.ui[class*="very compact"].table>tr>td {
  padding: 0.15em 0.1em;
}

.factlist li {
  word-wrap: break-word;
}

.ui.table.wrapped td {
  word-wrap: break-word;
}

.ui.label.status {
  color: white;
  text-shadow: 0 0 1px;
}

.ui.header.failed, .ui.line.failed {
  color: #AA4643;
}

.ui.label.failed, .ui.label.failure, .ui.label.events.failure {
  background-color: #AA4643;
}

.ui.header.changed, .ui.line.changed {
  color: #4572A7;
}

.ui.label.changed, .ui.label.success, .ui.label.events.success {
  background-color: #4572A7;
}

.ui.header.unreported {
  color: #3D96AE;
}

.ui.label.unreported {
  background-color: #3D96AE;
}

.ui.header.noop {
  color: #DB843D;
}

.ui.label.noop, .ui.label.events.noop {
  background-color: #DB843D;
}

.ui.label.resources.total, .ui.label.nodes.total {
  background-color: #989898;
}

.ui.header.unchanged {
  color: #89A54E;
}

.ui.label.unchanged {
  background-color: #89A54E;
}

.ui.line.skipped {
  color: orange;
}

.ui.label.skipped, .ui.label.resources.skipped {
  background-color: orange;
}

.count {
  width: 4em;
  text-align: center;
  display: block;
}

.absolute {
  position: fixed;
  bottom: 0;
  width: 100%;
  background: #E8E8E8;
}

.absolute div {
  padding: 1em;
}

.ui.menu.darkblue {
  background-color: #2C3E50;
  border-radius: 0px !important;
}

.ui.darkblue.header, i.darkblue {
  color: #2C3E50;
}

.ui.labels .darkblue.label::before, .ui.darkblue.labels .label::before, .ui.darkblue.label::before {
  background-color: #2C3E50;
}

.ui.darkblue.labels .label, .ui.darkblue.label {
  background-color: #2C3E50;
  border-color: #2C3E50;
  color: #FFF;
}

.ui.menu.yellow {
  background-color: #F0E965;
}

.ui.yellow.header, i.yellow {
  color: #F0E965;
}

.ui.labels .yellow.label::before, .ui.yellow.labels .label::before, .ui.yellow.label::before {
  background-color: #F0E965;
}

.ui.yellow.labels .label, .ui.yellow.label {
  background-color: #F0E965;
  border-color: #F0E965;
}

#scroll-btn-top {
  position: fixed;
  overflow: hidden;
  z-index: 99999999;
  opacity: 0;
  visibility: hidden;
  width: 50px;
  height: 48px;
  line-height: 48px;
  right: 30px;
  bottom: 85px;
  padding-top: 2px;
  background-color: #777777;
  text-align: center;
  color: #EEE;
  border-top-left-radius: 10px;
  border-top-right-radius: 10px;
  border-bottom-right-radius: 10px;
  border-bottom-left-radius: 10px;
  -webkit-transition: all 0.5s ease-in-out;
  -moz-transition: all 0.5s ease-in-out;
  -ms-transition: all 0.5s ease-in-out;
  -o-transition: all 0.5s ease-in-out;
  transition: all 0.5s ease-in-out;
}

#scroll-btn-top:hover {
  background-color: #888;
}

#scroll-btn-top.show {
  visibility: visible;
  cursor: pointer;
  opacity: 1.0;
}

#scroll-btn-top i {
  position: absolute;
  top: 50%;
  left: 50%;
  margin: 0;
  margin-right: -50%;
  transform: translate(-50%, -50%)
}

#dailyReportsChartContainer {
  height: 160px;
}

pre.json {
  padding: 0;
  margin: 0;
  font-family: "Open Sans", sans-serif;
}

.string {
  color: #2E5D8C;
}
a .string:hover {
  color: #1e70bf;
}
.number {
  color: darkorange;
}
a .number:hover {
  color: #ffab3d;
}
.boolean {
  color: blue;
}
a .boolean:hover {
  color: #7171fc;
}
.key {
  color: rgb(97, 117, 54);
}
a .key:hover {
  color: rgb(158, 185, 101);
}
.null {
  color: magenta;
}

textarea, /* query */
pre.result,
pre.error_message,
td.error_message,
td.code {
  font-family: "Cousine", monospace;
  font-size: 1rem;
}

.warning_message,
.info_message {
  font-size: 1rem;
}

#friendly_div {
  margin-bottom: 1em;
}

.ui.inverted.menu .active.item {
  background:rgba(255,255,255,.15);
  color:#fff!important
}

.ui.inverted.menu .active.item:hover {
  background:rgba(255,255,255,.15);
  color:#fff!important
}

.dataTables_length > label {
  margin-right: 1em;
}

#facts_table td {
  vertical-align: top;
}
