{% extends 'layout.html' %}
{% import '_macros.html' as macros %}
{% block content %}
<table id="catalogs_table" class='ui very basic table stackable'>
  <thead>
    <tr>
      {% for column in columns %}
      <th>{{ column.name }}</th>
      {% endfor %}
    </tr>
  </thead>
  <tbody>
  </tbody>
</table>
{% endblock content %}
{% block onload_script %}
{% macro extra_options(caller) %}
  "order": [[ 0, "asc" ]],
{% endmacro %}
{{ macros.datatable_init(table_html_id="catalogs_table", ajax_url=url_for('catalogs_ajax', env=current_env, compare=compare), data=None, default_length=config.NORMAL_TABLE_COUNT, length_selector=config.TABLE_COUNT_SELECTOR, extra_options=extra_options) }}
{% endblock onload_script %}
